Builds an augmented metadata data frame from the metadata and data given to 'learn()'. This augmented metadata object is saved in the 'learnt' object produced by 'learn()'.
buildauxmetadata(data, metadata, Dthreshold = 1, tscalefactor = 4.266)A data frame with auxmetadata.
data.frame object
data.frame object
Positive number: threshold of fraction of unique datapoints to total datapoints, to decide whether to treat a rounded variate as continuous
Positive number: scaling factor for variate conversion
In addition to the original metadata it contains info about transformed variates and their domains, estimated location- and scale-parameters, and similar metadata.
Used in 'learn()'.