Skip to contents

A data frame containing the prior information about all variates of the penguins dataset.

Usage

meta_penguins

Format

metadataExample

A data frame with 8 rows and 10 columns.

Value

No return value.

See also

datasets::penguins dataset.

metadatatemplate() which helps producing this kind of metadata files from a given dataset.

learn() which needs this kind of metadata files to "learn" from data.