A data frame containing the prior information about all variates of the penguins dataset.
Format
metadataExample
A data frame with 8 rows and 10 columns.
See also
datasets::penguins dataset.
metadatatemplate() which helps producing this kind of metadata files from a given dataset.
learn() which needs this kind of metadata files to "learn" from data.