A data frame containing the prior information about the variates species and bill_len of the datasets::penguins dataset.
Format
metadataExample
A data frame with 2 rows and 10 columns.
See also
metadatatemplate() which helps producing this kind of metadata files from a given dataset.
learn() which needs this kind of metadata files to "learn" from data.