powered by
A data frame containing the prior information about the variates species and bill_len of the datasets::penguins dataset.
species
bill_len
metadataExample
No return value.
A data frame with 2 rows and 10 columns.
metadatatemplate() which helps producing this kind of metadata files from a given dataset.
metadatatemplate()
learn() which needs this kind of metadata files to "learn" from data.
learn()