Learn R Programming

prova (version 1.0.0)

util_cleanup: Cleanup a learn()-output directory

Description

Cleanup a learn()-output directory

Usage

util_cleanup(path)

Arguments

Value

No return value; called for side effects.

Details

For deeper monitoring of the MCMC, the user can require the 'learn()' function not to clean intermediate MCMC-related files generated during the computation.

The present function can be used to remove these intermediate files from the output directory created by 'learn()'.